summaryrefslogtreecommitdiff
path: root/src/httpfetch.h
diff options
context:
space:
mode:
authorShadowNinja <shadowninja@minetest.net>2014-09-14 20:46:45 -0400
committerShadowNinja <shadowninja@minetest.net>2014-09-18 21:54:22 -0400
commit86a3c8ce566f28112dc032aa48c40e12fde97be2 (patch)
tree26b688e66efb45803081537023461c57991ef049 /src/httpfetch.h
parent18bfa1c785a123499ee12d0551a9447a4d32d93b (diff)
downloadminetest-86a3c8ce566f28112dc032aa48c40e12fde97be2.tar.gz
minetest-86a3c8ce566f28112dc032aa48c40e12fde97be2.tar.bz2
minetest-86a3c8ce566f28112dc032aa48c40e12fde97be2.zip
Reduce indentation of HTTPFetchOngoing
Also clean up some related things.
Diffstat (limited to 'src/httpfetch.h')
-rw-r--r--src/httpfetch.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/httpfetch.h b/src/httpfetch.h
index aba7482c2..50a4c93d8 100644
--- a/src/httpfetch.h
+++ b/src/httpfetch.h
@@ -88,14 +88,14 @@ struct HTTPFetchResult
request_id = 0;
}
- HTTPFetchResult(const HTTPFetchRequest &fetchrequest)
+ HTTPFetchResult(const HTTPFetchRequest &fetch_request)
{
succeeded = false;
timeout = false;
response_code = 0;
data = "";
- caller = fetchrequest.caller;
- request_id = fetchrequest.request_id;
+ caller = fetch_request.caller;
+ request_id = fetch_request.request_id;
}
};
@@ -107,11 +107,11 @@ void httpfetch_init(int parallel_limit);
void httpfetch_cleanup();
// Starts an asynchronous HTTP fetch request
-void httpfetch_async(const HTTPFetchRequest &fetchrequest);
+void httpfetch_async(const HTTPFetchRequest &fetch_request);
// If any fetch for the given caller ID is complete, removes it from the
-// result queue, sets fetchresult and returns true. Otherwise returns false.
-bool httpfetch_async_get(unsigned long caller, HTTPFetchResult &fetchresult);
+// result queue, sets the fetch result and returns true. Otherwise returns false.
+bool httpfetch_async_get(unsigned long caller, HTTPFetchResult &fetch_result);
// Allocates a caller ID for httpfetch_async
// Not required if you want to set caller = HTTPFETCH_DISCARD
@@ -124,8 +124,8 @@ void httpfetch_caller_free(unsigned long caller);
// Performs a synchronous HTTP request. This blocks and therefore should
// only be used from background threads.
-void httpfetch_sync(const HTTPFetchRequest &fetchrequest,
- HTTPFetchResult &fetchresult);
+void httpfetch_sync(const HTTPFetchRequest &fetch_request,
+ HTTPFetchResult &fetch_result);
#endif // !HTTPFETCH_HEADER